@@ -4,6 +4,7 @@
  *
  * Copyright (C) 2006-2007 Jody Goldberg (jody@gnome.org)
  * Copyright (C) 2011 Jean Brefort (jean.brefort@normalesup.org)
+ * Copyright (C) 2015 Morten Welinder (terra@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -128,10 +129,71 @@ xlsx_write_rgbarea (GsfXMLOut *xml, GOColor color)
 	gsf_xml_out_end_element (xml);
 }
 
+static gboolean
+xlsx_go_style_has_font (GOStyle *style)
+{
+	GOFont const *def;
+	gboolean is_def;
+
+	if (!(style->interesting_fields & GO_STYLE_FONT))
+		return FALSE;
+
+	/* We need to fix auto_font! */
+
+	def = go_font_new_by_index (0);
+	is_def = (style->font.font == def);
+	go_font_unref (def);
+
+	if (is_def)
+		return FALSE;
+
+	return TRUE /* !style->font.auto_font */;
+}
+
+static void
+xlsx_write_rpr (GsfXMLOut *xml, GOStyle *style)
+{
+	gboolean has_font_color = ((style->interesting_fields & GO_STYLE_FONT) &&
+				   !style->font.auto_color);
+	gboolean has_font = xlsx_go_style_has_font (style);
+
+	GOFont const *font = style->font.font;
+	PangoFontDescription *desc = font->desc;
+
+	if (has_font) {
+		int sz = pango_font_description_get_size (desc);
+		if (sz > 0) {
+			sz = CLAMP (sz, 1 * PANGO_SCALE, 4000 * PANGO_SCALE);
+			gsf_xml_out_add_uint (xml, "sz", sz * 100 / PANGO_SCALE);
+		}
+
+		if (pango_font_description_get_weight (desc) > PANGO_WEIGHT_NORMAL)
+			xlsx_add_bool (xml, "b", TRUE);
+		if (pango_font_description_get_style (desc) > PANGO_STYLE_NORMAL)
+			xlsx_add_bool (xml, "i", TRUE);
+	}
+	if (has_font_color) {
+		gsf_xml_out_start_element (xml, "a:solidFill");
+		xlsx_write_rgbarea (xml, style->font.color);
+		gsf_xml_out_end_element (xml);
+	}
+	if (has_font) {
+		gsf_xml_out_start_element (xml, "a:latin");
+		gsf_xml_out_add_cstr (xml, "typeface",
+				      pango_font_description_get_family (desc));
+		gsf_xml_out_end_element (xml);
+	}
+}
+
+
 static void
 xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style,
-			  gboolean def_has_markers)
+			  gboolean def_has_markers, gboolean def_has_lines)
 {
+	gboolean has_font_color = ((style->interesting_fields & GO_STYLE_FONT) &&
+				   !style->font.auto_color);
+	gboolean has_font = xlsx_go_style_has_font (style);
+
 	gsf_xml_out_start_element (xml, "c:spPr");
 
 	if ((style->interesting_fields & GO_STYLE_FILL) &&
@@ -165,7 +227,8 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style,
 	}
 
 	if ((style->interesting_fields & (GO_STYLE_LINE | GO_STYLE_OUTLINE)) &&
-	    (!style->line.auto_dash ||
+	    (!def_has_lines ||
+	     !style->line.auto_dash ||
 	     !style->line.auto_width ||
 	     !style->line.auto_color)) {
 		static const char * const dashes[] = {
@@ -182,7 +245,7 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style,
 			"dashDot",       /* GO_LINE_DASH_DOT */
 			"lgDashDot",     /* GO_LINE_DASH_DOT_DOT */
 		};
-		gboolean is_none = (style->line.dash_type == GO_LINE_NONE);
+		gboolean is_none = (!style->line.auto_dash && style->line.dash_type == GO_LINE_NONE);
 
 		gsf_xml_out_start_element (xml, "a:ln");
 		if (is_none) {
@@ -195,7 +258,8 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style,
 			gsf_xml_out_start_element (xml, "a:solidFill");
 			xlsx_write_rgbarea (xml, style->line.color);
 			gsf_xml_out_end_element (xml);
-		}
+		} else if (style->line.auto_dash && !def_has_lines)
+			gsf_xml_out_simple_element (xml, "a:noFill", NULL);
 
 		if (!style->line.auto_dash &&
 		    style->line.dash_type < G_N_ELEMENTS (dashes) &&
@@ -210,15 +274,29 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style,
 
 	gsf_xml_out_end_element (xml);  /* "c:spPr" */
 
+	if (has_font_color || has_font) {
+		gsf_xml_out_start_element (xml, "c:txPr");
+		gsf_xml_out_simple_element (xml, "a:bodyPr", NULL);
+		gsf_xml_out_simple_element (xml, "a:lstStyle", NULL);
+		gsf_xml_out_start_element (xml, "a:p");
+		gsf_xml_out_start_element (xml, "a:pPr");
+		gsf_xml_out_start_element (xml, "a:defRPr");
+		xlsx_write_rpr (xml, style);
+		gsf_xml_out_end_element (xml);  /* "a:defRPr" */
+		gsf_xml_out_end_element (xml);  /* "a:pPr" */
+		gsf_xml_out_end_element (xml);  /* "a:p" */
+		gsf_xml_out_end_element (xml);  /* "c:txPr" */
+	}
+
 	if (style->interesting_fields & GO_STYLE_MARKER) {
 		static const char *const markers[] = {
 			"none",       /* GO_MARKER_NONE */
 			"square",     /* GO_MARKER_SQUARE */
 			"diamond",    /* GO_MARKER_DIAMOND */
-			"triangle",   /* GO_MARKER_TRIANGLE_DOWN */   /* FIXME: rotation */
+			"triangle",   /* GO_MARKER_TRIANGLE_DOWN */
 			"triangle",   /* GO_MARKER_TRIANGLE_UP */
-			"triangle",   /* GO_MARKER_TRIANGLE_RIGHT */  /* FIXME: rotation */
-			"triangle",   /* GO_MARKER_TRIANGLE_LEFT */   /* FIXME: rotation */
+			"triangle",   /* GO_MARKER_TRIANGLE_RIGHT */
+			"triangle",   /* GO_MARKER_TRIANGLE_LEFT */
 			"circle",     /* GO_MARKER_CIRCLE */
 			"x",          /* GO_MARKER_X */
 			"plus",       /* GO_MARKER_CROSS */
@@ -229,6 +307,8 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style,
 			"diamond",    /* GO_MARKER_HOURGLASS */       /* FIXME: dubious */
 			"dot"         /* GO_MARKER_LEFT_HALF_BAR */
 		};
+		static gint8 nqturns[] = { 0, 0, 0, 2, 0, +1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
+		static gint8 flipH[] =   { 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0 };
 		gboolean need_spPr;
 		GOMarkerShape s = style->marker.auto_shape
 			? (def_has_markers ? GO_MARKER_MAX : GO_MARKER_NONE)
@@ -253,6 +333,15 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style,
 		if (need_spPr) {
 			gsf_xml_out_start_element (xml, "c:spPr");
 
+			if (nqturns[s] || flipH[s]) {
+				gsf_xml_out_start_element (xml, "a:xfrm");
+				if (nqturns[s])
+					gsf_xml_out_add_int (xml, "rot", nqturns[s] * (90 * 60000));
+				if (flipH[s])
+					gsf_xml_out_add_int (xml, "flipH", flipH[s]);
+				gsf_xml_out_end_element (xml);
+			}
+
 			if (!style->marker.auto_fill_color) {
 				gsf_xml_out_start_element (xml, "a:solidFill");
 				xlsx_write_rgbarea (xml, go_marker_get_fill_color (style->marker.mark));
@@ -277,21 +366,20 @@ xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style,
 static void
 xlsx_write_go_style (GsfXMLOut *xml, GOStyle *style)
 {
-	xlsx_write_go_style_full (xml, style, FALSE);
+	xlsx_write_go_style_full (xml, style, FALSE, TRUE);
 }
 
 static void
 xlsx_write_chart_text (XLSXWriteState *state, GsfXMLOut *xml,
 		       GOData *data, GogObject const *label)
 {
-	/* I don't really know what I am doing here.  */
 	char *text = go_data_get_scalar_string (data);
 	GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (label));
 	gboolean has_font_color = ((style->interesting_fields & GO_STYLE_FONT) &&
 				   !style->font.auto_color);
-	gboolean has_font = ((style->interesting_fields & GO_STYLE_FONT) &&
-			     TRUE /* !style->font.auto_font */);
+	gboolean has_font = xlsx_go_style_has_font (style);
 	gboolean allow_wrap;
+	GOStyle *style_minus_font;
 
 	gsf_xml_out_start_element (xml, "c:tx");
 	gsf_xml_out_start_element (xml, "c:rich");
@@ -306,33 +394,8 @@ xlsx_write_chart_text (XLSXWriteState *state, GsfXMLOut *xml,
 	gsf_xml_out_start_element (xml, "a:r");
 
 	if (has_font_color || has_font) {
-		GOFont const *font = style->font.font;
-		PangoFontDescription *desc = font->desc;
-
 		gsf_xml_out_start_element (xml, "a:rPr");
-		if (has_font) {
-			int sz = pango_font_description_get_size (desc);
-			if (sz > 0) {
-				sz = CLAMP (sz, 1 * PANGO_SCALE, 4000 * PANGO_SCALE);
-				gsf_xml_out_add_uint (xml, "sz", sz * 100 / PANGO_SCALE);
-			}
-
-			if (pango_font_description_get_weight (desc) > PANGO_WEIGHT_NORMAL)
-				xlsx_add_bool (xml, "b", TRUE);
-			if (pango_font_description_get_style (desc) > PANGO_STYLE_NORMAL)
-				xlsx_add_bool (xml, "i", TRUE);
-		}
-		if (has_font_color) {
-			gsf_xml_out_start_element (xml, "a:solidFill");
-			xlsx_write_rgbarea (xml, style->font.color);
-			gsf_xml_out_end_element (xml);
-		}
-		if (has_font) {
-			gsf_xml_out_start_element (xml, "a:latin");
-			gsf_xml_out_add_cstr (xml, "typeface",
-					      pango_font_description_get_family (desc));
-			gsf_xml_out_end_element (xml);
-		}
+		xlsx_write_rpr (xml, style);
 		gsf_xml_out_end_element (xml); /* </a:rPr> */
 	}
 
@@ -344,7 +407,10 @@ xlsx_write_chart_text (XLSXWriteState *state, GsfXMLOut *xml,
 	gsf_xml_out_end_element (xml); /* </c:rich> */
 	gsf_xml_out_end_element (xml); /* </c:tx> */
 
-	xlsx_write_go_style (xml, style);
+	style_minus_font = go_style_dup (style);
+	style_minus_font->interesting_fields &= ~GO_STYLE_FONT;
+	xlsx_write_go_style (xml, style_minus_font);
+	g_object_unref (style_minus_font);
 
 	g_free (text);
 }
@@ -369,6 +435,8 @@ xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogAxis *axis, GogAxisTy
 	GogGridLine *grid;
 	GogObject *label;
 	GOFormat *format;
+	double d;
+	gboolean user_defined;
 
 #ifdef DEBUG_AXIS
 	g_printerr ("Writing axis %s.  (discrete = %d)\n",
@@ -383,8 +451,12 @@ xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogAxis *axis, GogAxisTy
 	xlsx_write_chart_uint (xml, "c:axId", 0, xlsx_get_axid (state, axis));
 	gsf_xml_out_start_element (xml, "c:scaling");
 	xlsx_write_chart_cstr_unchecked (xml, "c:orientation", gog_axis_is_inverted (axis)? "maxMin": "minMax");
-	// TODO: export min, max, an others
+	d = gog_axis_get_entry (axis, GOG_AXIS_ELEM_MAX, &user_defined);
+	if (user_defined) xlsx_write_chart_float (xml, "c:max", go_nan, d);
+	d = gog_axis_get_entry (axis, GOG_AXIS_ELEM_MIN, &user_defined);
+	if (user_defined) xlsx_write_chart_float (xml, "c:min", go_nan, d);
 	gsf_xml_out_end_element (xml);
+	xlsx_write_chart_uint (xml, "c:delete", 1, 0);
 	/* FIXME position might be "t" or "r" */
 	xlsx_write_chart_cstr_unchecked (xml, "c:axPos", (at == GOG_AXIS_X || at == GOG_AXIS_CIRCULAR)? "b": "l");
 
@@ -419,6 +491,22 @@ xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogAxis *axis, GogAxisTy
 	gsf_xml_out_add_cstr (xml, "formatCode", (format)? go_format_as_XL (format): "General");
 	gsf_xml_out_end_element (xml);
 
+	{
+		gboolean mati, miti, mato, mito;
+		static const char *marks[4] = { "none", "in", "out", "cross" };
+
+		g_object_get (G_OBJECT (axis),
+			      "major-tick-in", &mati,
+			      "minor-tick-in", &miti,
+			      "major-tick-out", &mato,
+			      "minor-tick-out", &mito,
+			      NULL);
+		xlsx_write_chart_cstr_unchecked (xml, "c:majorTickMark",
+						 marks[2 * mato + mati]);
+		xlsx_write_chart_cstr_unchecked (xml, "c:minorTickMark",
+						 marks[2 * mito + miti]);
+	}
+
 	xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (axis)));
 
 	xlsx_write_chart_int (xml, "c:crossAx", 0, xlsx_get_axid (state, crossed));
@@ -426,9 +514,13 @@ xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogAxis *axis, GogAxisTy
 	switch (pos) {
 	default:
 	case GOG_AXIS_AT_LOW:
-		/* FIXME: might be wrong if the axis is inverted */
-		xlsx_write_chart_cstr_unchecked (xml, "c:crosses", "min");
+	case GOG_AXIS_AT_HIGH: {
+		gboolean is_low = (pos == GOG_AXIS_AT_LOW);
+		gboolean cross_inv = gog_axis_is_inverted (crossed);
+		xlsx_write_chart_cstr_unchecked (xml, "c:crosses",
+						 is_low ^ cross_inv ? "min" : "max");
 		break;
+	}
 	case GOG_AXIS_CROSS: {
 		double cross = gog_axis_base_get_cross_location (GOG_AXIS_BASE (axis));
 		if (cross == 0.)
@@ -437,11 +529,13 @@ xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogAxis *axis, GogAxisTy
 			xlsx_write_chart_float (xml, "c:crossesAt", 0., cross);
 		break;
 	}
-	case GOG_AXIS_AT_HIGH:
-		xlsx_write_chart_cstr_unchecked (xml, "c:crosses", "max");
-		break;
 	}
 
+	d = gog_axis_get_entry (axis, GOG_AXIS_ELEM_MAJOR_TICK, &user_defined);
+	if (user_defined && d > 0) xlsx_write_chart_float (xml, "c:majorUnit", go_nan, d);
+	d = gog_axis_get_entry (axis, GOG_AXIS_ELEM_MINOR_TICK, &user_defined);
+	if (user_defined && d > 0) xlsx_write_chart_float (xml, "c:minorUnit", go_nan, d);
+
 	/* finished with axis */
 	gsf_xml_out_end_element (xml);
 }
@@ -458,9 +552,11 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *cha
 	const char *plot_type_name;
 	GSList const *series;
 	unsigned count;
+	gboolean has_markers = FALSE;
+	gboolean has_lines = FALSE;
 	gboolean use_xy = FALSE;
 	gboolean set_smooth = FALSE;
-	gboolean has_markers = FALSE;
+	gboolean set_invert = FALSE;
 
 	g_object_get (G_OBJECT (plot),
 		      "vary-style-by-element", &vary_by_element,
@@ -495,6 +591,7 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *cha
 
 		xlsx_write_plot_1_5_type (xml, plot, TRUE);
 		xlsx_write_chart_bool (xml, "c:varyColors", vary_by_element);
+		set_invert = TRUE;
 		break;
 	}
 
@@ -503,6 +600,7 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *cha
 		xlsx_write_plot_1_5_type (xml, plot, FALSE);
 		xlsx_write_chart_bool (xml, "c:varyColors", vary_by_element);
 		set_smooth = TRUE;
+		has_lines = TRUE;
 		g_object_get (G_OBJECT (plot),
 		              "default-style-has-markers", &has_markers,
 		              NULL);
@@ -544,10 +642,11 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *cha
 		gsf_xml_out_start_element (xml, "c:bubbleChart");
 		xlsx_write_chart_bool (xml, "c:varyColors", vary_by_element);
 		use_xy = TRUE;
+		set_invert = TRUE;
 		break;
 
 	case XLSX_PT_GOGXYPLOT: {
-		gboolean has_lines, use_splines;
+		gboolean use_splines;
 		char const *style;
 		g_object_get (G_OBJECT (plot),
 		              "default-style-has-lines", &has_lines,
@@ -587,7 +686,9 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *cha
 		xlsx_write_chart_int (xml, "c:order", -1, count);
 		xlsx_write_series_dim (state, xml, ser, "c:tx", GOG_MS_DIM_LABELS);
 		if (!vary_by_element) /* FIXME: we might loose some style elements */
-			xlsx_write_go_style_full (xml, style, has_markers);
+			xlsx_write_go_style_full (xml, style, has_markers, has_lines);
+		if (set_invert)
+			xlsx_write_chart_uint (xml, "c:invertIfNegative", 1, 0);
 
 		children = gog_object_get_children (GOG_OBJECT (ser), NULL);
 		for (l = children; l; l = l->next) {
@@ -595,6 +696,8 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *cha
 			const char *trend_type_name = G_OBJECT_TYPE_NAME (trend);
 			const char *trend_type;
 			GogObject *eq;
+			GOData *dat;
+			char *name;
 
 			if (!GOG_IS_TREND_LINE (trend))
 				continue;
@@ -616,8 +719,11 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *cha
 				g_warning ("Unknown regression mapped to %s\n", trend_type);
 			}
 
-
 			gsf_xml_out_start_element (xml, "c:trendline");
+			dat = gog_dataset_get_dim (GOG_DATASET (trend), -1);
+			name = go_data_get_scalar_string (dat);
+			gsf_xml_out_simple_element (xml, "c:name", name);
+			g_free (name);
 			xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (trend)));
 			xlsx_write_chart_cstr_unchecked (xml, "c:trendlineType", trend_type);
 			gsf_xml_out_end_element (xml); /* </c:trendline> */
@@ -703,6 +809,11 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *cha
 		break;
 	}
 
+	case XLSX_PT_GOGLINEPLOT:
+		if (has_markers)
+			xlsx_write_chart_bool (xml, "c:marker", has_markers);
+		break;
+
 	default:
 		break; /* Nothing */
 	}
@@ -790,7 +901,6 @@ static void
 xlsx_write_chart (XLSXWriteState *state, GsfOutput *chart_part, SheetObject *so)
 {
 	GogGraph const *graph;
-	GogObject const	*chart;
 	GsfXMLOut *xml;
 
 	xml = gsf_xml_out_new (chart_part);
@@ -798,12 +908,20 @@ xlsx_write_chart (XLSXWriteState *state, GsfOutput *chart_part, SheetObject *so)
 	gsf_xml_out_add_cstr_unchecked (xml, "xmlns:c", ns_chart);
 	gsf_xml_out_add_cstr_unchecked (xml, "xmlns:a", ns_drawing);
 	gsf_xml_out_add_cstr_unchecked (xml, "xmlns:r", ns_rel);
+	xlsx_write_chart_uint (xml, "c:roundedCorners", 1, 0);
 
 	graph = sheet_object_graph_get_gog (so);
 	if (graph != NULL) {
-		chart = gog_object_get_child_by_name (GOG_OBJECT (graph), "Chart");
-		if (chart != NULL)
-			xlsx_write_one_chart (state, xml, chart);
+		GogObjectRole const *role = gog_object_find_role_by_name (GOG_OBJECT (graph), "Chart");
+		GSList *charts = gog_object_get_children (GOG_OBJECT (graph), role);
+		if (charts != NULL) {
+			GogObject const	*chart1 = charts->data;
+			xlsx_write_one_chart (state, xml, chart1);
+			if (charts->next)
+				g_warning ("Dropping %d charts on the floor!",
+					   g_slist_length (charts));
+			g_slist_free (charts);
+		}
 	}
 	gsf_xml_out_end_element (xml); /* </c:chartSpace> */
 	g_object_unref (xml);
