@@ -182,6 +182,16 @@ lpsolve_create_program (Sheet *sheet, GOIOContext *io_context,
 
 	/* ---------------------------------------- */
 
+	if (sp->options.model_type != GNM_SOLVER_LP) {
+		g_set_error (err,
+			     go_error_invalid (),
+			     0,
+			     _("Only linear programs are handled."));
+		goto fail;
+	}
+
+	/* ---------------------------------------- */
+
 	progress = 2;
 	if (sp->options.assume_non_negative) progress++;
 	if (sp->options.assume_discrete) progress++;
