@@ -238,14 +238,14 @@ fmt_dialog_changed (FormatState *state)
 	GOFormatSel *gfs;
 	GOFormat const *fmt;
 	gboolean ok;
-	
+
 	if (!state->enable_edit)
 		return;
-	
+
 	gfs = GO_FORMAT_SEL (state->format_sel);
 	fmt = go_format_sel_get_fmt (gfs);
 	ok = !go_format_is_invalid (fmt);
-	
+
 	gtk_widget_set_sensitive (state->apply_button, ok);
 	gtk_widget_set_sensitive (state->ok_button, ok);
 }
@@ -304,7 +304,8 @@ setup_pattern_button (GdkScreen *screen,
 		      GtkBuilder  *gui,
 		      char const *const name,
 		      PatternPicker *picker,
-		      gboolean const flag,
+		      gboolean do_image,
+		      gboolean from_icon,
 		      int const index,
 		      int const select_index,
 		      unsigned size)
@@ -312,12 +313,12 @@ setup_pattern_button (GdkScreen *screen,
 	GtkWidget *tmp = go_gtk_builder_get_widget (gui, name);
 	if (tmp != NULL) {
 		GtkButton *button = GTK_BUTTON (tmp);
-		if (flag) {
-			GdkPixbuf *pixbuf = gtk_icon_theme_load_icon (
-				gtk_icon_theme_get_for_screen (screen),
-				name, size, 0, NULL);
-			GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
-			g_object_unref (pixbuf);
+		if (do_image) {
+			char *res = g_strconcat ("/org/gnumeric/gnumeric/images/", name, ".xpm", NULL);
+			GtkWidget *image = from_icon
+				? gtk_image_new_from_icon_name (name, GTK_ICON_SIZE_DIALOG)
+				: gtk_image_new_from_resource (res);
+			g_free (res);
 			gtk_widget_show (image);
 			gtk_container_add (GTK_CONTAINER (tmp), image);
 		}
@@ -424,28 +425,6 @@ setup_color_pickers (FormatState *state,
 	}
 }
 
-/*
- * Utility routine to load an image and insert it into a
- * button of the same name.
- */
-static GtkWidget *
-init_button_image (GtkBuilder *gui, char const *name)
-{
-	GtkWidget *tmp = go_gtk_builder_get_widget (gui, name);
-	if (tmp != NULL) {
-		GdkScreen *screen = gtk_widget_get_screen (tmp);
-		GdkPixbuf *pixbuf = gtk_icon_theme_load_icon (
-			gtk_icon_theme_get_for_screen (screen),
-			name, 16, 0, NULL);
-		GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
-		g_object_unref (pixbuf);
-		gtk_widget_show (image);
-		gtk_container_add (GTK_CONTAINER (tmp), image);
-	}
-
-	return tmp;
-}
-
 /*****************************************************************************/
 
 static void
@@ -1683,6 +1662,28 @@ validation_rebuild_validation (FormatState *state)
 	fmt_dialog_changed (state);
 }
 
+static struct {
+	const char *text;
+	const char *icon_name;
+} validation_error_actions[] = {
+	{
+		N_("None          (silently accept invalid input)"),
+		NULL
+	},
+	{
+		N_("Stop            (never allow invalid input)"),
+		"dialog-error"
+	},
+	{
+		N_("Warning     (accept/discard invalid input)"),
+		"dialog-warning"
+	},
+	{
+		N_("Information (allow invalid input)"),
+		"dialog-information"
+	}
+};
+
 static void
 cb_validation_error_action_changed (G_GNUC_UNUSED GtkMenuShell *ignored,
 				    FormatState *state)
@@ -1697,20 +1698,9 @@ cb_validation_error_action_changed (G_GNUC_UNUSED GtkMenuShell *ignored,
 	gtk_widget_set_sensitive (GTK_WIDGET (state->validation.error.msg), flag);
 
 	if (flag) {
-		char const *s = NULL;
-
-		switch (index) {
-		case 1: s = GTK_STOCK_DIALOG_ERROR;	break;
-		case 2: s = GTK_STOCK_DIALOG_WARNING;	break;
-		case 3: s = GTK_STOCK_DIALOG_INFO;	break;
-		default:
-			g_warning ("Unknown validation style");
-			return;
-		}
-
-		if (s != NULL)
-			gtk_image_set_from_stock (state->validation.error.image,
-						  s, GTK_ICON_SIZE_MENU);
+		char const *icon_name = validation_error_actions[index].icon_name;
+		gtk_image_set_from_icon_name (state->validation.error.image,
+					      icon_name, GTK_ICON_SIZE_DIALOG);
 		gtk_widget_show (GTK_WIDGET (state->validation.error.image));
 	} else
 		gtk_widget_hide (GTK_WIDGET (state->validation.error.image));
@@ -1828,46 +1818,31 @@ cb_validation_rebuild (G_GNUC_UNUSED void *ignored,
 }
 
 static void
-build_validation_error_combo (GtkComboBox *box)
+build_validation_error_combo (FormatState *state, GtkComboBox *box)
 {
-	GdkPixbuf *pixbuf;
 	GtkListStore *store;
-	GtkTreeIter iter;
 	GtkCellRenderer *renderer;
+	unsigned ui;
 
 	store = gtk_list_store_new (2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
 	gtk_combo_box_set_model (box, GTK_TREE_MODEL (store));
 
-	gtk_list_store_append (store, &iter);
-	gtk_list_store_set (store, &iter,
-			    1, _("None          (silently accept invalid input)"),
-			    -1);
+	for (ui = 0; ui < G_N_ELEMENTS (validation_error_actions); ui++) {
+		const char *icon_name = validation_error_actions[ui].icon_name;
+		GdkPixbuf *pixbuf = icon_name
+			? go_gtk_widget_render_icon_pixbuf (GTK_WIDGET (wbcg_toplevel (state->wbcg)),
+							    icon_name, GTK_ICON_SIZE_MENU)
+			: NULL;
+		GtkTreeIter iter;
 
-	pixbuf = gtk_widget_render_icon_pixbuf (GTK_WIDGET (box), GTK_STOCK_STOP,
-					 GTK_ICON_SIZE_BUTTON);
-	gtk_list_store_append (store, &iter);
-	gtk_list_store_set (store, &iter,
-			    0, pixbuf,
-			    1, _("Stop            (never allow invalid input)"),
-			    -1);
-
-	pixbuf = gtk_widget_render_icon_pixbuf (GTK_WIDGET (box),
-					 GTK_STOCK_DIALOG_WARNING,
-					 GTK_ICON_SIZE_BUTTON);
-	gtk_list_store_append (store, &iter);
-	gtk_list_store_set (store, &iter,
-			    0, pixbuf,
-			    1, _("Warning     (accept/discard invalid input)"),
-			    -1);
-
-	pixbuf = gtk_widget_render_icon_pixbuf (GTK_WIDGET (box),
-					 GTK_STOCK_DIALOG_INFO,
-					 GTK_ICON_SIZE_BUTTON);
-	gtk_list_store_append (store, &iter);
-	gtk_list_store_set (store, &iter,
-			    0, pixbuf,
-			    1, _("Information (allow invalid input)"),
-			    -1);
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+				    0, pixbuf,
+				    1, _(validation_error_actions[ui].text),
+				    -1);
+		if (pixbuf)
+			g_object_unref (pixbuf);
+	}
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (box),
@@ -1909,7 +1884,7 @@ fmt_dialog_init_validation_page (FormatState *state)
 	state->validation.error.title_label  = GTK_LABEL       (go_gtk_builder_get_widget (state->gui, "validation_error_title_label"));
 	state->validation.error.msg_label    = GTK_LABEL       (go_gtk_builder_get_widget (state->gui, "validation_error_msg_label"));
 	state->validation.error.action       = GTK_COMBO_BOX (go_gtk_builder_get_widget (state->gui, "validation_error_action"));
-	build_validation_error_combo (state->validation.error.action);
+	build_validation_error_combo (state, state->validation.error.action);
 	gtk_combo_box_set_active (state->validation.error.action, 0);
 	state->validation.error.title        = GTK_ENTRY       (go_gtk_builder_get_widget (state->gui, "validation_error_title"));
 	state->validation.error.msg          = GTK_TEXT_VIEW   (go_gtk_builder_get_widget (state->gui, "validation_error_msg"));
@@ -2210,7 +2185,7 @@ set_initial_focus (FormatState *s)
 	else if (strcmp (name, "font_box") == 0)
 	      focus_widget = GTK_WIDGET (s->font.selector);
 	else if (strcmp (name, "border_box") == 0)
-	      focus_widget = go_gtk_builder_get_widget (s->gui, "outline_border");
+	      focus_widget = go_gtk_builder_get_widget (s->gui, "gnumeric-format-border-outline");
 	else if (strcmp (name, "background_box") == 0)
 	      focus_widget = go_gtk_builder_get_widget (s->gui, "back_color_auto");
 	else if (strcmp (name, "protection_box") == 0)
@@ -2255,45 +2230,45 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno, gint pages)
 		{ NULL, 0}
 	};
 	static char const *const pattern_buttons[] = {
-		"gp_solid", "gp_75grey", "gp_50grey",
-		"gp_25grey", "gp_125grey", "gp_625grey",
+		"gnumeric-pattern-solid", "gnumeric-pattern-75grey", "gnumeric-pattern-50grey",
+		"gnumeric-pattern-25grey", "gnumeric-pattern-125grey", "gnumeric-pattern-625grey",
 
-		"gp_horiz",
-		"gp_vert",
-		"gp_diag",
-		"gp_rev_diag",
-		"gp_diag_cross",
-		"gp_thick_diag_cross",
+		"gnumeric-pattern-horiz",
+		"gnumeric-pattern-vert",
+		"gnumeric-pattern-diag",
+		"gnumeric-pattern-rev-diag",
+		"gnumeric-pattern-diag-cross",
+		"gnumeric-pattern-thick-diag-cross",
 
-		"gp_thin_horiz",
-		"gp_thin_vert",
-		"gp_thin_rev_diag",
-		"gp_thin_diag",
-		"gp_thin_horiz_cross",
-		"gp_thin_diag_cross",
+		"gnumeric-pattern-thin-horiz",
+		"gnumeric-pattern-thin-vert",
+		"gnumeric-pattern-thin-rev-diag",
+		"gnumeric-pattern-thin-diag",
+		"gnumeric-pattern-thin-horiz-cross",
+		"gnumeric-pattern-thin-diag-cross",
 
-		"gp_small_circle",
-		"gp_semi_circle",
-		"gp_thatch",
-		"gp_large_circles",
-		"gp_bricks",
-		"gp_foreground_solid",
+		"gnumeric-pattern-small-circle",
+		"gnumeric-pattern-semi-circle",
+		"gnumeric-pattern-thatch",
+		"gnumeric-pattern-large-circles",
+		"gnumeric-pattern-bricks",
+		"gnumeric-pattern-foreground-solid",
 
 		NULL
 	};
 
 	/* The order corresponds to the BorderLocation enum */
 	static char const *const border_buttons[] = {
-		"top_border",	"bottom_border",
-		"left_border",	"right_border",
-		"rev_diag_border",	"diag_border",
-		"inside_horiz_border", "inside_vert_border",
+		"gnumeric-format-border-top",	"gnumeric-format-border-bottom",
+		"gnumeric-format-border-left",	"gnumeric-format-border-right",
+		"gnumeric-format-border-rev-diag",	"gnumeric-format-border-diag",
+		"gnumeric-format-border-inside-horiz", "gnumeric-format-border-inside-vert",
 		NULL
 	};
 
 	/* The order corresponds to BorderPresets */
 	static char const *const border_preset_buttons[] = {
-		"no_border", "outline_border", "inside_border",
+		"gnumeric-format-border-no", "gnumeric-format-border-outline", "gnumeric-format-border-inside",
 		NULL
 	};
 
@@ -2366,6 +2341,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno, gint pages)
 		setup_pattern_button (gtk_widget_get_screen (GTK_WIDGET (state->dialog)),
 				      state->gui, name, &state->border.pattern,
 				      i != 0, /* No image for None */
+				      FALSE,
 				      line_pattern_buttons[i].pattern,
 				      default_border_style, 54);
 
@@ -2384,7 +2360,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno, gint pages)
 
 	/* Setup the border images */
 	for (i = 0; (name = border_buttons[i]) != NULL; ++i) {
-		tmp = init_button_image (state->gui, name);
+		GtkWidget *tmp = go_gtk_builder_get_widget (state->gui, name);
 		if (tmp != NULL) {
 			init_border_button (state, i, tmp,
 					    state->borders[i]);
@@ -2415,7 +2391,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno, gint pages)
 	for (i = 0; (name = pattern_buttons[i]) != NULL; ++i)
 		setup_pattern_button (gtk_widget_get_screen (GTK_WIDGET (state->dialog)),
 				      state->gui, name,
-				      &state->back.pattern, TRUE,
+				      &state->back.pattern, TRUE, TRUE,
 				      i+1, /* Pattern #s start at 1 */
 				      selected, 16);
 
@@ -2427,7 +2403,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno, gint pages)
 
 	/* Setup the images in the border presets */
 	for (i = 0; (name = border_preset_buttons[i]) != NULL; ++i) {
-		tmp = init_button_image (state->gui, name);
+		GtkWidget *tmp = go_gtk_builder_get_widget (state->gui, name);
 		if (tmp != NULL) {
 			state->border.preset[i] = GTK_BUTTON (tmp);
 			g_signal_connect (G_OBJECT (tmp),
@@ -2622,7 +2598,7 @@ dialog_cell_format (WBCGtk *wbcg, FormatDialogPosition_t pageno, gint pages)
 	if (pages == 0) {
 		int i;
 		for (i = FD_NUMBER; i <= FD_PROTECTION; i++)
-			pages |= (1 << i); 
+			pages |= (1 << i);
 	}
 
 	fmt_dialog_impl (state, pageno, pages);
