@@ -546,21 +546,18 @@ cb_name_guru_destroy (NameGuruState *state)
 	WorkbookControl *wbc = WORKBOOK_CONTROL (state->wbcg);
 
 	wb_view_selection_desc (wb_control_view (wbc), TRUE, wbc);
-	if (state->gui != NULL) {
-		g_object_unref (state->gui);
-		state->gui = NULL;
-	}
+	g_clear_object (&state->gui);
+	g_clear_object (&state->model);
 
-	if (state->is_paste_dialog)
-		g_object_unref (state->image_paste);
-	else {
+	if (!state->is_paste_dialog)
 		wbcg_edit_finish (state->wbcg, WBC_EDIT_REJECT, NULL);
-		g_object_unref (state->image_add);
-		g_object_unref (state->image_delete);
-		g_object_unref (state->image_lock);
-		g_object_unref (state->image_up);
-		g_object_unref (state->image_down);
-	}
+
+	g_clear_object (&state->image_paste);
+	g_clear_object (&state->image_add);
+	g_clear_object (&state->image_delete);
+	g_clear_object (&state->image_lock);
+	g_clear_object (&state->image_up);
+	g_clear_object (&state->image_down);
 
 	state->dialog = NULL;
 	g_free (state);
@@ -1051,11 +1048,11 @@ cb_name_guru_selection_function (G_GNUC_UNUSED GtkTreeSelection *selection,
 static gboolean
 name_guru_init (NameGuruState *state, WBCGtk *wbcg, gboolean is_paste_dialog)
 {
-	Workbook          *wb = wb_control_get_workbook
-		(WORKBOOK_CONTROL (wbcg));
+	Workbook *wb = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
 	GtkTreeViewColumn *column;
 	GtkCellRenderer   *renderer;
 	GtkTreeSelection  *selection;
+	GtkWidget *widget = GTK_WIDGET (wbcg_toplevel (wbcg));
 
 	state->is_paste_dialog = is_paste_dialog;
 	state->has_pasted = FALSE;
@@ -1181,10 +1178,7 @@ name_guru_init (NameGuruState *state, WBCGtk *wbcg, gboolean is_paste_dialog)
 				  "changed",
 				  G_CALLBACK (name_guru_update_sensitivity),
 				  state);
-		state->image_paste = gtk_widget_render_icon_pixbuf
-			(state->dialog,
-			 GTK_STOCK_PASTE,
-			 GTK_ICON_SIZE_SMALL_TOOLBAR);
+		state->image_paste = go_gtk_widget_render_icon_pixbuf (widget, "edit-paste", GTK_ICON_SIZE_MENU);
 		state->image_add    = NULL;
 		state->image_delete = NULL;
 		state->image_lock   = NULL;
@@ -1192,44 +1186,14 @@ name_guru_init (NameGuruState *state, WBCGtk *wbcg, gboolean is_paste_dialog)
 		state->image_down   = NULL;
 	} else {
 		state->image_paste = NULL;
-		state->image_add =  gtk_widget_render_icon_pixbuf
-			(state->dialog,
-			 GTK_STOCK_ADD,
-			 GTK_ICON_SIZE_SMALL_TOOLBAR);
-		state->image_delete =  gtk_widget_render_icon_pixbuf
-			(state->dialog,
-			 GTK_STOCK_REMOVE,
-			 GTK_ICON_SIZE_SMALL_TOOLBAR);
-		state->image_lock =  gtk_widget_render_icon_pixbuf
-			(state->dialog,
-			 "Gnumeric_Protection_Yes",
-			 GTK_ICON_SIZE_SMALL_TOOLBAR);
-		state->image_up =  gtk_widget_render_icon_pixbuf
-			(state->dialog,
-			 GTK_STOCK_GO_UP,
-			 GTK_ICON_SIZE_SMALL_TOOLBAR);
-		state->image_down =  gtk_widget_render_icon_pixbuf
-			(state->dialog,
-			 GTK_STOCK_GO_DOWN,
-			 GTK_ICON_SIZE_SMALL_TOOLBAR);
+		state->image_add = go_gtk_widget_render_icon_pixbuf (widget, "list-add", GTK_ICON_SIZE_MENU);
+		state->image_delete = go_gtk_widget_render_icon_pixbuf (widget, "list-remove", GTK_ICON_SIZE_MENU);
+		state->image_lock = go_gtk_widget_render_icon_pixbuf (widget, "gnumeric-protection-yes", GTK_ICON_SIZE_MENU);
+		state->image_up = go_gtk_widget_render_icon_pixbuf (widget, "go-up", GTK_ICON_SIZE_MENU);
+		state->image_down = go_gtk_widget_render_icon_pixbuf (widget, "go-down", GTK_ICON_SIZE_MENU);
 	}
 
-	state->search_entry = go_gtk_builder_get_widget (state->gui,
-						    "search_entry");
-
-	gtk_entry_set_icon_from_stock
-		(GTK_ENTRY (state->search_entry),
-		 GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_CLEAR);
-	gtk_entry_set_icon_tooltip_text
-		(GTK_ENTRY (state->search_entry),
-		 GTK_ENTRY_ICON_SECONDARY,
-		 _("Erase the search entry."));
-	gtk_entry_set_icon_sensitive
-		(GTK_ENTRY (state->search_entry),
-		 GTK_ENTRY_ICON_SECONDARY, TRUE);
-	gtk_entry_set_icon_activatable
-		(GTK_ENTRY (state->search_entry),
-		 GTK_ENTRY_ICON_SECONDARY, TRUE);
+	state->search_entry = go_gtk_builder_get_widget (state->gui, "search_entry");
 
 	g_signal_connect (G_OBJECT (state->search_entry),
 			  "icon-press",
