@@ -296,30 +296,30 @@ dhl_get_target_url (HyperlinkState *state, gboolean *success)
 
 static struct {
 	char const *label;
-	char const *image_name;
+	char const *icon_name;
 	char const *name;
 	char const *widget_name;
 	char const *descriptor;
 	void (*set_target) (HyperlinkState *state, const char* const target);
 	char * (*get_target) (HyperlinkState *state, gboolean *success);
-} const type [] = {
-	{ N_("Internal Link"), "Gnumeric_Link_Internal",
+} const type[] = {
+	{ N_("Internal Link"), "gnumeric-link-internal",
 	  "GnmHLinkCurWB",	"internal-link-grid",
 	  N_("Jump to specific cells or named range in the current workbook"),
 	  dhl_set_target_cur_wb,
 	  dhl_get_target_cur_wb },
 
-	{ N_("External Link"), "Gnumeric_Link_External",
+	{ N_("External Link"), "gnumeric-link-external",
 	  "GnmHLinkExternal",	"external-link-grid" ,
 	  N_("Open an external file with the specified name"),
 	  dhl_set_target_external,
 	  dhl_get_target_external },
-	{ N_("Email Link"),	"Gnumeric_Link_EMail",
+	{ N_("Email Link"),	"gnumeric-link-email",
 	  "GnmHLinkEMail",	"email-grid" ,
 	  N_("Prepare an email"),
 	  dhl_set_target_email,
 	  dhl_get_target_email },
-	{ N_("Web Link"),		"Gnumeric_Link_URL",
+	{ N_("Web Link"),		"gnumeric-link-url",
 	  "GnmHLinkURL",	"url-grid" ,
 	  N_("Browse to the specified URL"),
 	  dhl_set_target_url,
@@ -429,9 +429,9 @@ dhl_setup_type (HyperlinkState *state)
 
 		if (!strcmp (name, type[i].name)) {
 			gtk_widget_show_all (w);
-			gtk_image_set_from_stock
-				(state->type_image, type[i].image_name,
-				 GTK_ICON_SIZE_LARGE_TOOLBAR);
+			gtk_image_set_from_icon_name
+				(state->type_image, type[i].icon_name,
+				 GTK_ICON_SIZE_DIALOG);
 			gtk_label_set_text (state->type_descriptor,
 					    _(type[i].descriptor));
 		} else
@@ -476,7 +476,6 @@ dhl_init (HyperlinkState *state)
 	GtkSizeGroup *size_group;
 	GnmExprEntry *expr_entry;
 	unsigned i, select = 0;
-	GdkPixbuf *pixbuf;
 	GtkListStore *store;
 	GtkTreeIter iter;
 	GtkCellRenderer *renderer;
@@ -524,13 +523,15 @@ dhl_init (HyperlinkState *state)
 	g_object_unref (store);
 
 	for (i = 0 ; i < G_N_ELEMENTS (type); i++) {
-		pixbuf = gtk_widget_render_icon_pixbuf (w, type[i].image_name,
-						 GTK_ICON_SIZE_MENU);
+		GdkPixbuf *pixbuf = go_gtk_widget_render_icon_pixbuf
+			(GTK_WIDGET (wbcg_toplevel (state->wbcg)),
+			 type[i].icon_name, GTK_ICON_SIZE_MENU);
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
 				    0, pixbuf,
 				    1, _(type[i].label),
 				    -1);
+		g_object_unref (pixbuf);
 
 		if (strcmp (G_OBJECT_TYPE_NAME (state->link),
 			    type [i].name) == 0)
