@@ -1098,36 +1098,35 @@ hf_insert_hf_stock_tag (HFCustomizeState *hf_state, GtkTextBuffer *buffer,
 			HFFieldType type, const char *options)
 {
 	GtkTextIter iter;
-	gchar const *stock_id;
+	gchar const *icon_name;
 	GdkPixbuf* pix;
 	GtkTextMark *new_mark;
 	HFMarkInfo *mark_info;
 
-
 	switch (type) {
 	case HF_FIELD_FILE:
-		stock_id = GTK_STOCK_FILE;
+		icon_name = GTK_STOCK_FILE;
 		break;
 	case HF_FIELD_PATH:
-		stock_id = GTK_STOCK_DIRECTORY;
+		icon_name = "folder";
 		break;
 	case HF_FIELD_PAGE:
-		stock_id = "Gnumeric_Pagesetup_HF_Page";
+		icon_name = "gnumeric-pagesetup-hf-page";
 		break;
 	case HF_FIELD_PAGES:
-		stock_id = "Gnumeric_Pagesetup_HF_Pages";
+		icon_name = "gnumeric-pagesetup-hf-pages";
 		break;
 	case HF_FIELD_DATE:
-		stock_id = "Gnumeric_Pagesetup_HF_Date";
+		icon_name = "gnumeric-pagesetup-hf-date";
 		break;
 	case HF_FIELD_TIME:
-		stock_id = "Gnumeric_Pagesetup_HF_Time";
+		icon_name = "gnumeric-pagesetup-hf-time";
 		break;
 	case HF_FIELD_SHEET:
-		stock_id = "Gnumeric_Pagesetup_HF_Sheet";
+		icon_name = "gnumeric-pagesetup-hf-sheet";
 		break;
 	case HF_FIELD_CELL:
-		stock_id = "Gnumeric_Pagesetup_HF_Cell";
+		icon_name = "gnumeric-pagesetup-hf-cell";
 		break;
 	default:
 		return;
@@ -1137,13 +1136,14 @@ hf_insert_hf_stock_tag (HFCustomizeState *hf_state, GtkTextBuffer *buffer,
 
 	if (gtk_text_buffer_insert_interactive_at_cursor
 	    (buffer, "", -1, TRUE)) {
+		GtkWidget *w = GTK_WIDGET (wbcg_toplevel (hf_state->printer_setup_state->wbcg));
+
 		gtk_text_buffer_get_iter_at_mark
 			(buffer, &iter, gtk_text_buffer_get_insert (buffer));
 
-		pix = gtk_widget_render_icon_pixbuf (GTK_WIDGET (hf_state->dialog),
-					      stock_id,
-					      GTK_ICON_SIZE_MENU);
+		pix = go_gtk_widget_render_icon_pixbuf (w, icon_name, GTK_ICON_SIZE_BUTTON);
 		gtk_text_buffer_insert_pixbuf (buffer, &iter, pix);
+		g_object_unref (pix);
 		gtk_text_iter_backward_char (&iter);
 		new_mark = gtk_text_buffer_create_mark (buffer, NULL,
 							&iter, FALSE);
@@ -1796,29 +1796,29 @@ do_hf_customize (gboolean header, PrinterSetupState *state)
 		 "clicked", G_CALLBACK (hf_delete_tag_cb), hf_state);
 
 	button = GTK_TOOL_BUTTON (go_gtk_builder_get_widget (gui, "insert-date-button"));
-	gtk_tool_button_set_stock_id (button, "Gnumeric_Pagesetup_HF_Date");
+	gtk_tool_button_set_icon_name (button, "gnumeric-pagesetup-hf-date");
 	hf_attach_insert_date_menu (GTK_MENU_TOOL_BUTTON (button), hf_state);
 
 	button = GTK_TOOL_BUTTON (go_gtk_builder_get_widget (gui, "insert-page-button"));
-	gtk_tool_button_set_stock_id (button, "Gnumeric_Pagesetup_HF_Page");
+	gtk_tool_button_set_icon_name (button, "gnumeric-pagesetup-hf-page");
 	g_signal_connect_swapped
 		(G_OBJECT (button),
 		 "clicked", G_CALLBACK (hf_insert_page_cb), hf_state);
 
 	button = GTK_TOOL_BUTTON (go_gtk_builder_get_widget (gui, "insert-pages-button"));
-	gtk_tool_button_set_stock_id (button, "Gnumeric_Pagesetup_HF_Pages");
+	gtk_tool_button_set_icon_name (button, "gnumeric-pagesetup-hf-pages");
 	g_signal_connect_swapped
 		(G_OBJECT (button),
 		 "clicked", G_CALLBACK (hf_insert_pages_cb), hf_state);
 
 	button = GTK_TOOL_BUTTON (go_gtk_builder_get_widget (gui, "insert-sheet-button"));
-	gtk_tool_button_set_stock_id (button, "Gnumeric_Pagesetup_HF_Sheet");
+	gtk_tool_button_set_icon_name (button, "gnumeric-pagesetup-hf-sheet");
 	g_signal_connect_swapped
 		(G_OBJECT (button),
 		 "clicked", G_CALLBACK (hf_insert_sheet_cb), hf_state);
 
 	button = GTK_TOOL_BUTTON (go_gtk_builder_get_widget (gui, "insert-time-button"));
-	gtk_tool_button_set_stock_id (button, "Gnumeric_Pagesetup_HF_Time");
+	gtk_tool_button_set_icon_name (button, "gnumeric-pagesetup-hf-time");
 	hf_attach_insert_time_menu (GTK_MENU_TOOL_BUTTON (button), hf_state);
 
 	g_signal_connect_swapped
@@ -1830,7 +1830,7 @@ do_hf_customize (gboolean header, PrinterSetupState *state)
 		 "clicked", G_CALLBACK (hf_insert_path_cb), hf_state);
 
 	button = GTK_TOOL_BUTTON (go_gtk_builder_get_widget (gui, "insert-cell-button"));
-	gtk_tool_button_set_stock_id (button, "Gnumeric_Pagesetup_HF_Cell");
+	gtk_tool_button_set_icon_name (button, "gnumeric-pagesetup-hf-cell");
 	hf_attach_insert_cell_menu (GTK_MENU_TOOL_BUTTON (button), hf_state);
 
 
@@ -2313,8 +2313,8 @@ do_setup_page_info (PrinterSetupState *state)
 							 (GTK_COMBO_BOX (state->comment_display.combo)));
 	do_setup_comment_display (state);
 
-	state->icon_rd = gnumeric_load_image ("res:gnm:pixmaps/right-down.png");
-	state->icon_dr = gnumeric_load_image ("res:gnm:pixmaps/down-right.png");
+	state->icon_rd = gtk_image_new_from_resource ("/org/gnumeric/gnumeric/images/right-down.png");
+	state->icon_dr = gtk_image_new_from_resource ("/org/gnumeric/gnumeric/images/down-right.png");
 
 	gtk_widget_hide (state->icon_dr);
 	gtk_widget_hide (state->icon_rd);
