@@ -1434,9 +1434,13 @@ dialog_sheet_order (WBCGtk *wbcg)
 	GtkGrid *grid;
 	GOColorGroup *cg;
 	Workbook *wb;
+	GtkWidget *widget;
+	GdkPixbuf *icon;
 
 	g_return_if_fail (wbcg != NULL);
 
+	widget = GTK_WIDGET (wbcg_toplevel (wbcg));
+
 	gui = gnm_gtk_builder_load ("sheet-order.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return;
@@ -1472,21 +1476,11 @@ dialog_sheet_order (WBCGtk *wbcg)
 	state->cancel_btn  = go_gtk_builder_get_widget (gui, "cancel_button");
 	state->advanced_check  = go_gtk_builder_get_widget (gui, "advanced-check");
 	state->initial_colors_set = FALSE;
-	state->image_padlock =  gtk_widget_render_icon_pixbuf (state->dialog,
-                                             "Gnumeric_Protection_Yes",
-                                             GTK_ICON_SIZE_LARGE_TOOLBAR);
-	state->image_padlock_no =  gtk_widget_render_icon_pixbuf (state->dialog,
-                                             "Gnumeric_Protection_No",
-                                             GTK_ICON_SIZE_LARGE_TOOLBAR);
-	state->image_visible = gtk_widget_render_icon_pixbuf (state->dialog,
-                                             "Gnumeric_Visible",
-                                             GTK_ICON_SIZE_LARGE_TOOLBAR);
-	state->image_ltr =  gtk_widget_render_icon_pixbuf (state->dialog,
-                                             "gtk-go-forward",
-                                             GTK_ICON_SIZE_LARGE_TOOLBAR);
-	state->image_rtl =  gtk_widget_render_icon_pixbuf (state->dialog,
-                                             "gtk-go-back",
-                                             GTK_ICON_SIZE_LARGE_TOOLBAR);
+	state->image_padlock = go_gtk_widget_render_icon_pixbuf (widget, "gnumeric-protection-yes", GTK_ICON_SIZE_MENU);
+	state->image_padlock_no = go_gtk_widget_render_icon_pixbuf (widget, "gnumeric-protection-no", GTK_ICON_SIZE_MENU);
+	state->image_visible = go_gtk_widget_render_icon_pixbuf (widget, "gnumeric-visible", GTK_ICON_SIZE_MENU);
+	state->image_ltr = go_gtk_widget_render_icon_pixbuf (widget, "format-text-direction-ltr", GTK_ICON_SIZE_MENU);
+	state->image_rtl = go_gtk_widget_render_icon_pixbuf (widget, "format-text-direction-rtl", GTK_ICON_SIZE_MENU);
 	/* Listen for changes in the sheet order. */
 	state->sheet_order_changed_listener = g_signal_connect (G_OBJECT (wb),
 		"sheet_order_changed", G_CALLBACK (cb_sheet_order_changed),
@@ -1501,9 +1495,9 @@ dialog_sheet_order (WBCGtk *wbcg)
 	grid = GTK_GRID (go_gtk_builder_get_widget (gui,"main-grid"));
 	cg = go_color_group_fetch ("back_color_group",
 		wb_control_view (WORKBOOK_CONTROL (wbcg)));
-	state->ccombo_back = go_combo_color_new (
-		gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), "bucket", 24, 0, NULL),
-		_("Default"), 0, cg);
+	icon = go_gtk_widget_render_icon_pixbuf (widget, "gnumeric-bucket", GTK_ICON_SIZE_LARGE_TOOLBAR);
+	state->ccombo_back = go_combo_color_new (icon, _("Default"), 0, cg);
+	g_object_unref (icon);
 	g_object_unref (cg);
 	go_combo_color_set_instant_apply (
 		GO_COMBO_COLOR (state->ccombo_back), TRUE);
@@ -1512,9 +1506,9 @@ dialog_sheet_order (WBCGtk *wbcg)
 
 	cg = go_color_group_fetch ("fore_color_group",
 		wb_control_view (WORKBOOK_CONTROL (wbcg)));
-	state->ccombo_fore = go_combo_color_new (
-		gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), "font", 24, 0, NULL),
-		_("Default"), 0, cg);
+	icon = go_gtk_widget_render_icon_pixbuf (widget, "font", GTK_ICON_SIZE_LARGE_TOOLBAR);
+	state->ccombo_fore = go_combo_color_new (icon, _("Default"), 0, cg);
+	g_object_unref (icon);
 	g_object_unref (cg);
 	go_combo_color_set_instant_apply (
 		GO_COMBO_COLOR (state->ccombo_fore), TRUE);
