@@ -5,6 +5,7 @@
  * Author:
  *     Miguel de Icaza (miguel@kernel.org)
  *     Jody Goldberg   (jody@gnome.org)
+ *     Copyright 2015 by Morten Welinder (terra@gnome.org).
  */
 
 #include <gnumeric-config.h>
@@ -112,75 +113,80 @@ ic_reload_style (GnmItemCursor *ic)
 	GocItem *item = GOC_ITEM (ic);
 	GtkStyleContext *context = goc_item_get_style_context (item);
 	GtkStateFlags state = GTK_STATE_FLAG_NORMAL;
+	struct {
+		const char *class;
+		int fore_offset, back_offset;
+	} substyles[] = {
+		{ "normal",
+		  G_STRUCT_OFFSET (GnmItemCursor, normal_color),
+		  -1 },
+		{ "ant",
+		  G_STRUCT_OFFSET (GnmItemCursor, ant_color),
+		  G_STRUCT_OFFSET (GnmItemCursor, ant_background_color) },
+		{ "drag",
+		  G_STRUCT_OFFSET (GnmItemCursor, drag_color),
+		  G_STRUCT_OFFSET (GnmItemCursor, drag_background_color) },
+		{ "autofill",
+		  G_STRUCT_OFFSET (GnmItemCursor, autofill_color),
+		  G_STRUCT_OFFSET (GnmItemCursor, autofill_background_color) }
+	};
+	unsigned ui;
 
-	gtk_style_context_save (context);
-	gtk_style_context_add_class (context, "normal");
-	gtk_style_context_get_color (context, state, &ic->normal_color);
-	gtk_style_context_restore (context);
+	for (ui = 0; ui < G_N_ELEMENTS (substyles); ui++) {
+		GdkRGBA *fore, *back;
+		gtk_style_context_save (context);
+		gtk_style_context_add_class (context, substyles[ui].class);
+		gtk_style_context_get (context, state,
+				       "color", &fore,
+				       "background-color", &back,
+				       NULL);
+		*(GdkRGBA *)((char *)ic + substyles[ui].fore_offset) = *fore;
+		if (substyles[ui].back_offset >= 0)
+			*(GdkRGBA *)((char *)ic + substyles[ui].back_offset) = *back;
+		gdk_rgba_free (fore);
+		gdk_rgba_free (back);
+		gtk_style_context_restore (context);
+	}
 
-	gtk_style_context_save (context);
-	gtk_style_context_add_class (context, "ant");
-	gtk_style_context_get_color (context, state, &ic->ant_color);
-	gtk_style_context_get_background_color (context, state,
-						&ic->ant_background_color);
-	gtk_style_context_restore (context);
 	/*
 	 * Ensure we don't use transparency to avoid compositing issues
 	 * when redrawing the ants in the timer callback.
 	 */
 	ic->ant_color.alpha = ic->ant_background_color.alpha = 1.;
-
-	gtk_style_context_save (context);
-	gtk_style_context_add_class (context, "drag");
-	gtk_style_context_get_color (context, state, &ic->drag_color);
-	gtk_style_context_get_background_color (context, state,
-						&ic->drag_background_color);
-	gtk_style_context_restore (context);
-
-	gtk_style_context_save (context);
-	gtk_style_context_add_class (context, "autofill");
-	gtk_style_context_get_color (context, state, &ic->autofill_color);
-	gtk_style_context_get_background_color (context, state,
-						&ic->autofill_background_color);
-	gtk_style_context_restore (context);
 }
 
 static int
 cb_item_cursor_animation (GnmItemCursor *ic)
 {
 	GocItem *item = GOC_ITEM (ic);
-	static int use_fallback = -1;
+	cairo_region_t *region;
+	cairo_rectangle_int_t rect;
+	int x0, x1, y0, y1;
+	double scale = item->canvas->pixels_per_unit;
 
+	/* we need to use canvas coordinates in goc_canvas_c2w, hence the divisions by scale. */
+	if (goc_canvas_get_direction (item->canvas) == GOC_DIRECTION_RTL) {
+		goc_canvas_c2w (item->canvas, ic->outline.x2 / scale, ic->outline.y2 / scale, &x0, &y1);
+		goc_canvas_c2w (item->canvas, ic->outline.x1 / scale, ic->outline.y1 / scale, &x1, &y0);
+		x0--; /* because of the +.5, things are not symetric */
+		x1--;
+	} else {
+		goc_canvas_c2w (item->canvas, ic->outline.x1 / scale, ic->outline.y1 / scale, &x0, &y0);
+		goc_canvas_c2w (item->canvas, ic->outline.x2 / scale, ic->outline.y2 / scale, &x1, &y1);
+	}
 	ic->ant_state++;
-
-	if (use_fallback != 1) {
-		GdkWindow *w = gtk_widget_get_window (GTK_WIDGET (item->canvas));
-		cairo_t *cr = gdk_cairo_create (w);
-
-		if (use_fallback == -1) {
-			/*
-			 * Under some themes we get a (0,0,0,0) clip and
-			 * our drawing does nothing.  Detect this and
-			 * fall back to full invalidation.
-			 */
-			double cx0, cy0, cx1, cy1;
-			cairo_clip_extents (cr, &cx0, &cy0, &cx1, &cy1);
-			use_fallback = (cx0 == 0 && cy0 == 0 && cx1 == 0 && cy1 == 0);
-			if (use_fallback == 1 && gnm_debug_flag ("ant"))
-				g_printerr ("Using ant-ing fallback\n");
-		}
-
-		if (use_fallback == 0)
-			goc_item_draw (item, cr);
-
-		cairo_destroy (cr);
-	}
-
-	if (use_fallback == 1) {
-		if (ic->ant_state % 2 == 1)
-			goc_item_invalidate (item);
-	}
-
+	rect.x = x0 - 1;
+	rect.y = y0 - 1;
+	rect.width = x1 - x0 + 3;
+	rect.height = y1 - y0 + 3;
+	region = cairo_region_create_rectangle (&rect);
+	rect.x += 3;
+	rect.y += 3;
+	rect.width -= 6;
+	rect.height -= 6;
+	cairo_region_xor_rectangle (region, &rect);
+	goc_canvas_invalidate_region (item->canvas, item, region);
+	cairo_region_destroy (region);
 	return TRUE;
 }
 
@@ -818,7 +824,7 @@ item_cursor_popup_menu (GnmItemCursor *ic, GdkEvent *event)
 		{ N_("_Move"),		NULL,
 		    0, 0, ACTION_MOVE_CELLS },
 
-		{ N_("_Copy"),		GTK_STOCK_COPY,
+		{ N_("_Copy"), "edit-copy",
 		    0, 0, ACTION_COPY_CELLS },
 
 		{ N_("Copy _Formats"),		NULL,
@@ -1486,7 +1492,7 @@ gnm_item_cursor_class_init (GObjectClass *gobject_klass)
 		g_param_spec_uint ("color",
 				   P_("Color"),
 				   P_("Name of the cursor's color"),
-				   0, 0xffffffff, 
+				   0, 0xffffffff,
 				   GO_COLOR_BLACK,
 				   GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 
