@@ -462,8 +462,8 @@ gee_set_with_icon (GnmExprEntry *gee, gboolean with_icon)
 	if (with_icon) {
 		gee->icon = gtk_toggle_button_new ();
 		gtk_container_add (GTK_CONTAINER (gee->icon),
-				   gtk_image_new_from_stock ("Gnumeric_ExprEntry",
-							     GTK_ICON_SIZE_MENU));
+				   gtk_image_new_from_icon_name ("gnumeric-exprentry",
+								 GTK_ICON_SIZE_MENU));
 		gtk_box_pack_end (GTK_BOX (gee), gee->icon, FALSE, FALSE, 0);
 		gtk_widget_show_all (gee->icon);
 		g_signal_connect (gee->icon, "clicked",
@@ -675,7 +675,6 @@ gee_scan_for_range (GnmExprEntry *gee)
 						this_colour = colour++;
 						g_hash_table_insert (hash, rrr, GINT_TO_POINTER (this_colour));
 						insert_cursor = TRUE;
-						rtext = NULL;
 					} else {
 						this_colour = GPOINTER_TO_INT (val);
 						insert_cursor = FALSE;
@@ -2772,7 +2771,7 @@ gnm_expr_entry_is_cell_ref (GnmExprEntry *gee, Sheet *sheet,
         if (val == NULL)
 		return FALSE;
 
-	res = ((val->type == VALUE_CELLRANGE) &&
+	res = ((VALUE_IS_CELLRANGE (val)) &&
 	       (allow_multiple_cell ||
 		((val->v_range.cell.a.col == val->v_range.cell.b.col) &&
 		 (val->v_range.cell.a.row == val->v_range.cell.b.row))));
@@ -2814,7 +2813,7 @@ gnm_expr_entry_global_range_name (GnmExprEntry *gee, Sheet *sheet)
 
 	val = gnm_expr_entry_parse_as_value (gee, sheet);
 	if (val != NULL) {
-		if (val->type == VALUE_CELLRANGE)
+		if (VALUE_IS_CELLRANGE (val))
 			text = value_get_as_string (val);
 		value_release (val);
 	}
@@ -2844,25 +2843,6 @@ gnm_expr_entry_editing_canceled (GnmExprEntry *gee)
 
 /*****************************************************************************/
 
-void
-gnm_expr_entry_disable_highlight (GnmExprEntry *gee)
-{
-	g_return_if_fail (gee != NULL);
-	gee_destroy_feedback_range (gee);
-	gee->feedback_disabled = TRUE;
-}
-
-void
-gnm_expr_entry_enable_highlight (GnmExprEntry *gee)
-{
-	g_return_if_fail (gee != NULL);
-	gee->feedback_disabled = FALSE;
-	gee_update_lexer_items (gee);
-	gee_scan_for_range (gee);
-}
-
-/*****************************************************************************/
-
 void
 gnm_expr_entry_disable_tips (GnmExprEntry *gee)
 {
